<?php

require __DIR__ . '/vendor/autoload.php';

use Dotenv\Dotenv;

// Load .env file
$dotenv = Dotenv::createImmutable(__DIR__);
if (file_exists(__DIR__ . '/.env')) {
    $dotenv->load();
}

// Check if the Tengr.ai API key exists
$apiKey = $_ENV['TENGR_API_KEY'] ?? null;
if (!$apiKey) {
    echo "API key not found. Please enter your Tengr.ai API key:\n";
    $apiKey = trim(fgets(STDIN));

    // Read the existing content of the .env file
    $envPath = __DIR__ . '/.env';
    $existingContent = file_exists($envPath) ? file_get_contents($envPath) : '';

    // Check if the TENGR_API_KEY variable already exists in the file
    if (strpos($existingContent, 'TENGR_API_KEY=') !== false) {
        // Replace the value of the TENGR_API_KEY variable
        $newContent = preg_replace('/^TENGR_API_KEY=.*$/m', "TENGR_API_KEY=$apiKey", $existingContent);
    } else {
        // Add the new variable to the end of the file
        $newContent = $existingContent . "\nTENGR_API_KEY=$apiKey\n";
    }

    // Save the updated content back to the .env file
    file_put_contents($envPath, trim($newContent) . "\n");

    echo "API key saved successfully!\n";

    // Reload .env file
    $dotenv->load();
}


// Check if the bot token exists
$botToken = $_ENV['BOT_TOKEN'] ?? null;
if (!$botToken) {
    echo "Bot token not found. Please enter your bot token:\n";
    $botToken = trim(fgets(STDIN));

    // Read the existing content of the .env file
    $envPath = __DIR__ . '/.env';
    $existingContent = file_exists($envPath) ? file_get_contents($envPath) : '';

    // Check if the BOT_TOKEN variable already exists in the file
    if (strpos($existingContent, 'BOT_TOKEN=') !== false) {
        // Replace the value of the BOT_TOKEN variable
        $newContent = preg_replace('/^BOT_TOKEN=.*$/m', "BOT_TOKEN=$botToken", $existingContent);
    } else {
        // Add the new variable to the end of the file
        $newContent = $existingContent . "\nBOT_TOKEN=$botToken\n";
    }

    // Save the updated content back to the .env file
    file_put_contents($envPath, trim($newContent) . "\n");

    echo "Bot token saved successfully!\n";

    // Reload .env file
    $dotenv->load();
}

// Check if the Webhook URL exists
$webhookUrl = $_ENV['WEBHOOK_URL'] ?? null;
if (!$webhookUrl) {
    echo "Webhook URL not found. Please enter global address of your bot.php file\n (e.g. https://example.com/bot/bot.php):\n";
    $webhookUrl = trim(fgets(STDIN));

    // Read the existing content of the .env file
    $envPath = __DIR__ . '/.env';
    $existingContent = file_exists($envPath) ? file_get_contents($envPath) : '';

    // Check if the WEBHOOK_URL variable already exists in the file
    if (strpos($existingContent, 'WEBHOOK_URL=') !== false) {
        // Replace the value of the WEBHOOK_URL variable
        $newContent = preg_replace('/^WEBHOOK_URL=.*$/m', "WEBHOOK_URL=$webhookUrl", $existingContent);
    } else {
        // Add the new variable to the end of the file
        $newContent = $existingContent . "\nWEBHOOK_URL=$webhookUrl\n";
    }

    // Save the updated content back to the .env file
    file_put_contents($envPath, trim($newContent) . "\n");

    // Reload .env file
    $dotenv->load();

    // Send request to Telegram API to set bot webhook
    $url = 'https://api.telegram.org/bot' . $_ENV['BOT_TOKEN'] . '/setWebhook?url=' . $_ENV['WEBHOOK_URL'];
    $webhookResponse = file_get_contents($url);

    $webhookResponse = json_decode($webhookResponse, true);

    if (isset($webhookResponse['ok']) && $webhookResponse['ok'] === true) {
        echo "Webhook set successfully!\n". $_ENV['WEBHOOK_URL'];
    } else {
        echo "Webhook set failed!\n";
    }
}

echo "Bot is ready to use with API key: $apiKey and Bot token: $botToken and Webhook URL: $webhookUrl\n";

require __DIR__ . '/functions.php';

// Get the raw input from the incoming update
$content = file_get_contents('php://input');

// Decode the JSON content into a PHP associative array
$update = json_decode($content, true);

// Extract user message details from the update
$update_id = $update['update_id'];  // ID of the update
$chat_id = $update['message']['chat']['id'];  // User chat ID
$text = $update['message']['text'];  // Text of the user’s message
$message_id = $update['message']['message_id'];  // ID of the message
$user_id = $update['message']['chat']['username'];  // Username of the user
$user_name = $update['message']['chat']['first_name'];  // First name of the user

// Extract callback query details if available
$callback_chat_id = $update['callback_query']['message']['chat']['id'] ?? null;  // Chat ID from callback
$callback_data = $update['callback_query']['data'] ?? null;  // Data from the callback
$callback_id = $update['callback_query']['id'] ?? null;  // ID of the callback
$callback_message = $update['callback_query']['message']['text'] ?? null;  // Message text from callback
$callback_message_id = $update['callback_query']['message']['message_id'] ?? null;  // Message ID from callback
$bot_id = $update['callback_query']['from']['id'] ?? null;  // Bot ID from callback
// msg('setWebhook', ['url' => $_ENV['WEBHOOK_URL']]);

if ($text == '/start') {
    // msg('sendMessage', ['chat_id' => $chat_id, 'text' => 'Bot is ready to use with API key: ' . $apiKey . ' and Bot token: ' . $botToken . ' and Webhook URL: ' . $webhookUrl]);
    msg('sendMessage', [
        'chat_id' => $chat_id,
        'text' => '👋 سلام، به بات NoticApp خوش آمدید! لطفا یکی از دستورات زیر را انتخاب کنید:',
    ]);
}